==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/organiseur/lang/organiseur_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/organiseur?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_enregistrer_brouillon' => 'Enregistrer en brouillon',
	'bouton_envoyer_message' => 'Envoyer',
	'bouton_envoyer_message_maintenant' => 'Envoyer maintenant',

	// C
	'cal_jour_entier' => 'Journée',
	'cal_par_jour' => 'jour',
	'cal_par_mois' => 'mois',
	'cal_par_semaine' => 'semaine',

	// E
	'erreur_date' => 'Cette date est incorrecte',
	'erreur_date_avant_apres' => 'Indique une date de fin après la date de début !',
	'erreur_date_corrigee' => 'La date a été corrigée',
	'erreur_destinataire_invalide' => 'Le destinataire @dest@ n’est pas valide',
	'erreur_heure' => 'Cette heure est incorrecte',
	'erreur_heure_corrigee' => 'L’heure a été corrigée',

	// I
	'icone_ecrire_nouveau_message' => 'Envoyer un nouveau message',
	'icone_ecrire_nouveau_pensebete' => 'Écrire un nouveau pense-bête',
	'icone_ecrire_nouvelle_annonce' => 'Envoyer une nouvelle annonce',
	'icone_effacer_message' => 'Effacer ce message',
	'icone_modifier_annonce' => 'Modifier cette annonce',
	'icone_modifier_pensebete' => 'Modifier ce pense-bête',
	'icone_supprimer_message' => 'Supprimer ce message',
	'info_1_message_envoye' => '1 message envoyé',
	'info_1_message_nonlu' => '1 nouveau message',
	'info_agenda_interne' => 'Agenda interne',
	'info_message_a' => 'À',
	'info_message_date' => 'Date',
	'info_message_date_debut' => 'Date début',
	'info_message_date_fin' => 'Date fin',
	'info_message_de' => 'De',
	'info_message_non_lu' => 'Nouveau message',
	'info_message_objet' => 'Objet',
	'info_nb_messages_envoyes' => '@nb@ messages envoyés',
	'info_nb_messages_nonlus' => '@nb@ nouveaux messages',
	'info_selection_annonces' => 'Annonces',
	'info_selection_messages' => 'Messages',
	'info_selection_pensebetes' => 'Pense-bêtes',
	'info_type_message_affich' => 'Annonce',
	'info_type_message_normal' => 'Message',
	'info_type_message_pb' => 'Pense-bête',
	'info_type_message_rv' => 'Rendez-vous',

	// L
	'label_destinataires' => 'À',
	'label_texte' => 'Texte',
	'label_titre' => 'Sujet',
	'loading' => 'Chargement…',

	// M
	'message' => 'Message',
	'messages' => 'Messages',

	// N
	'notification_annonce_lire_a_ladresse' => 'Tu peux la lire à l’adresse suivante @url@.',
	'notification_annonce_publie_1' => '[@nom_site_spip@] Annonce générale',
	'notification_message_lire_a_ladresse' => 'Tu peux le lire et y répondre à l’adresse suivante @url@.',
	'notification_message_publie_1' => '[@nom_site_spip@] Nouveau message',
	'notification_message_recu_de' => 'Tu as reçu un nouveau message de la part de @nom@.',

	// T
	'texte_message_brouillon' => 'Ce message est enregistré comme brouillon',
	'titre_agenda_rv' => 'Rendez-vous',
	'titre_boite_envoi' => 'Boîte d’envoi',
	'titre_boite_reception' => 'Boîte de reception'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/organiseur/lang/organiseur_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/organiseur?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_enregistrer_brouillon' => 'Enregistrer en brouillon',
	'bouton_envoyer_message' => 'Envoyer',
	'bouton_envoyer_message_maintenant' => 'Envoyer maintenant',

	// C
	'cal_jour_entier' => 'Journée',
	'cal_par_jour' => 'jour',
	'cal_par_mois' => 'mois',
	'cal_par_semaine' => 'semaine',

	// E
	'erreur_date' => 'Cette date est incorrecte',
	'erreur_date_avant_apres' => 'Indique une date de fin après la date de début !',
	'erreur_date_corrigee' => 'La date a été corrigée',
	'erreur_destinataire_invalide' => 'Le destinataire @dest@ n’est pas valide',
	'erreur_heure' => 'Cette heure est incorrecte',
	'erreur_heure_corrigee' => 'L’heure a été corrigée',

	// I
	'icone_ecrire_nouveau_message' => 'Envoyer un nouveau message',
	'icone_ecrire_nouveau_pensebete' => 'Écrire un nouveau pense-bête',
	'icone_ecrire_nouvelle_annonce' => 'Envoyer une nouvelle annonce',
	'icone_effacer_message' => 'Effacer ce message',
	'icone_modifier_annonce' => 'Modifier cette annonce',
	'icone_modifier_message' => 'Modifier ce message',
	'icone_modifier_pensebete' => 'Modifier ce pense-bête',
	'icone_supprimer_message' => 'Supprimer ce message',
	'info_1_message_envoye' => '1 message envoyé',
	'info_1_message_nonlu' => '1 nouveau message',
	'info_agenda_interne' => 'Agenda interne',
	'info_message_a' => 'À',
	'info_message_date' => 'Date',
	'info_message_date_debut' => 'Date début',
	'info_message_date_fin' => 'Date fin',
	'info_message_de' => 'De',
	'info_message_non_lu' => 'Nouveau message',
	'info_message_objet' => 'Objet',
	'info_nb_messages_envoyes' => '@nb@ messages envoyés',
	'info_nb_messages_nonlus' => '@nb@ nouveaux messages',
	'info_selection_annonces' => 'Annonces',
	'info_selection_messages' => 'Messages',
	'info_selection_pensebetes' => 'Pense-bêtes',
	'info_type_message_affich' => 'Annonce',
	'info_type_message_normal' => 'Message',
	'info_type_message_pb' => 'Pense-bête',
	'info_type_message_rv' => 'Rendez-vous',

	// L
	'label_destinataires' => 'À',
	'label_texte' => 'Texte',
	'label_titre' => 'Sujet',
	'loading' => 'Chargement…',

	// M
	'message' => 'Message',
	'messages' => 'Messages',

	// N
	'notification_annonce_lire_a_ladresse' => 'Tu peux la lire à l’adresse suivante @url@.',
	'notification_annonce_publie_1' => '[@nom_site_spip@] Annonce générale',
	'notification_message_lire_a_ladresse' => 'Tu peux le lire et y répondre à l’adresse suivante @url@.',
	'notification_message_publie_1' => '[@nom_site_spip@] Nouveau message',
	'notification_message_recu_de' => 'Tu as reçu un nouveau message de la part de @nom@.',

	// T
	'texte_message_brouillon' => 'Ce message est enregistré comme brouillon',
	'titre_agenda_rv' => 'Rendez-vous',
	'titre_boite_envoi' => 'Boîte d’envoi',
	'titre_boite_reception' => 'Boîte de reception'
);

?>
